import { each, includes, keys } from 'lodash'
import { documentHelpers, FontAwesomeIcon as Icon, Tool } from 'substance'
import PromptTextArea from './PromptTextArea'

class EditNoteTool extends Tool {
  render ($$) {
    let el = $$('div').addClass('sc-edit-note-tool')

    const selected = this.getSelection()
    if (!selected.node) return el

    // TODO -- on this.getLabel add a label to package and call it save note
    const icon = $$(Icon, { icon: 'fa-save' })
      .addClass('sc-save-icon')
    const save = $$('div').addClass('sc-save-area').append(icon).on('click', this.saveNote)

    el.append(
      $$('div').addClass('sc-edit-note-tool-container').append(
        $$(PromptTextArea, {
          path: [selected.node.id, 'note-content'],
          placeholder: 'Type your note here'
        }),
        save
      )
    )

    // to properly adjust text area height depending on text
    this.setTextAreaHeight()

    return el
  }

  saveNote (event) {
    const selected = this.getSelection()
    const noteContent = this.el.find('textarea').val()
    const documentSession = this.context.documentSession

    documentSession.transaction(function (tx, args) {
      const path = [selected.node.id, 'note-content']
      tx.set(path, noteContent)
    })
  }

  getSelection () {
    // TODO -- write cleaner
    const surface = this.context.surfaceManager.getFocusedSurface()
    if (!surface) return {}

    const commandStates = this.context.commandManager.getCommandStates()
    const session = this.context.documentSession
    const sel = session.getSelection()

    const note = documentHelpers.getPropertyAnnotationsForSelection(
      session.getDocument(),
      sel,
      { type: 'note' }
    )

    // disable when larger selection that just includes a note as well
    const selectionLength = (sel.endOffset - sel.startOffset === 1)

    if (typeof note[0] !== 'undefined' && selectionLength) {
      // disable commands that don't make sense on a note
      each(keys(commandStates), (key) => {
        const allowed = ['comment', 'redo', 'save', 'switch-text-type', 'undo']
        if (!includes(allowed, key)) commandStates[key].disabled = true
      })

      return {
        node: note[0]
      }
    } else {
      return {
        node: null
      }
    }
  }

  // TODO -- duplicate code from propmt text area file in same folder??
  setTextAreaHeight () {
    setTimeout(function () {
      let textarea = document.querySelector('.se-note-textarea')

      if (textarea) {
        textarea.style.height = (textarea.scrollHeight) + 'px'
      }
    })
  }
}

EditNoteTool.type = 'edit-note'

export default EditNoteTool
